# Python Copy and Paste standard Library

Python Copy and Paste standard library (CPSTL) is a repository with a collection of data structure and algorithms.

## TODO
Add more content


## License

<div align="center">
  <img src="https://opensource.org/files/osi_keyhole_300X300_90ppi_0.png" width="150" height="150"/>
</div>

    Collection of algorithm's and data struct developer in different language
    and with the Code Style guide line, to resolve Competitive Programming problem.
    Copyright (C) 2020-2021 Vincenzo Palazzo vincenzopalazzodev@gmail.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.